# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

"""add-env-to-container

Revision ID: 5977879072a7
Revises: 417917e778f5
Create Date: 2015-11-26 04:10:39.462966

"""

# revision identifiers, used by Alembic.
revision = '5977879072a7'
down_revision = '417917e778f5'

from alembic import op  # noqa: E402
import sqlalchemy as sa  # noqa: E402


def upgrade():
    op.add_column('container', sa.Column('environment',
                                         sa.Text(), nullable=True))
